==> Sumu-Perl-Modules-0.3.7.tar.gz: Sumu-Perl-Modules-0.3.7/README.md <==
# Sumu::Perl::Modules 

Sat Sep 28 11:01:36 CDT 2024

## Description

Display all your installed Perl Modules

and

display perldoc for a selected module

## Installation

cpanm Sumu::Perl::Modules

or 

cpanm CEEJAY/Sumu-Perl-Modules-0.1.1.tar.gz

## USAGE

Clone this repo to get started 




### Latest Update/Release Info 

Latest Update/release info (added automatically)


#### 20240928195449CDT

	012\|013
	0.1.2\|0.1.3


#### 20240928195649CDT

	013|014
	0.1.3|0.1.4


#### 20240928195922CDT

	Commit ID: 014|015
	Version ID: 0.1.4|0.1.5


#### 20240928200135CDT

	Commit ID: Old 015 | New 016
	Version ID: Old 0.1.5 | New 0.1.6


#### 2024-09-28 20:05:50 CDT

	Commit ID: Old 016 | New 017
	Version ID: Old 0.1.6 | New 0.1.7


#### 2024-09-28 20:08:31 CDT

	Commit ID: Old 017 | New 018
	Version ID: Old 0.1.7 | New 0.1.8


#### 2024-09-28 20:09:13 CDT

	Commit ID: Old 018 | New 019
	Version ID: Old 0.1.8 | New 0.1.9


#### 2024-09-28 20:11:23 CDT

	Commit ID: Old 019 | New 020
	Version ID: Old 0.1.9 | New 0.2.0


#### 2024-09-28 20:19:35 CDT

	Commit ID: Old 020 | New 021
	Version ID: Old 0.2.0 | New 0.2.1


#### 2024-09-28 20:23:35 CDT

	Commit ID: Old 021 | New 022
	Version ID: Old 0.2.1 | New 0.2.2


#### 2024-09-28 20:27:22 CDT

	Commit ID: Old 022 | New 023
	Version ID: Old 0.2.2 | New 0.2.3


#### 2024-09-28 20:30:08 CDT

	Commit ID: Old 023 | New 024
	Version ID: Old 0.2.3 | New 0.2.4


#### 2024-09-28 20:30:54 CDT

	Commit ID: Old 024 | New 025
	Version ID: Old 0.2.4 | New 0.2.5


#### 2024-09-28 20:44:09 CDT

	Commit ID: Old 025 | New 026
	Version ID: Old 0.2.5 | New 0.2.6


#### 2024-09-28 20:49:41 CDT

	Commit ID: Old 026 | New 027
	Version ID: Old 0.2.6 | New 0.2.7


#### 2024-09-28 20:57:00 CDT

	Commit ID: Old 027 | New 028
	Version ID: Old 0.2.7 | New 0.2.8


#### 2024-09-28 20:59:35 CDT

	Commit ID: Old 028 | New 029
	Version ID: Old 0.2.8 | New 0.2.9


#### 2024-09-28 21:10:49 CDT

	Commit ID: Old 029 | New 030
	Version ID: Old 0.2.9 | New 0.3.0


#### 2024-09-28 21:31:35 CDT

	Commit ID: Old 030 | New 031
	Version ID: Old 0.3.0 | New 0.3.1


#### 2024-09-28 21:34:08 CDT

	Commit ID: Old 031 | New 032
	Version ID: Old 0.3.1 | New 0.3.2


#### 2024-09-28 21:44:41 CDT

	Commit ID: Old 032 | New 033
	Version ID: Old 0.3.2 | New 0.3.3


#### 2024-09-29 08:46:47 CDT

	Commit ID: Old 033 | New 034
	Version ID: Old 0.3.3 | New 0.3.4


#### 2024-09-30 07:33:47 CDT

	Commit ID: Old 034 | New 035
	Version ID: Old 0.3.4 | New 0.3.5


#### 2024-09-30 07:59:07 CDT

	Commit ID: Old 035 | New 036
	Version ID: Old 0.3.5 | New 0.3.6


#### 2024-09-30 08:41:46 CDT

	Commit ID: Old 036 | New 037
	Version ID: Old 0.3.6 | New 0.3.7

==> Sumu-Perl-Modules-0.4.0.tar.gz: Sumu-Perl-Modules-0.4.0/README.md <==
# Sumu::Perl::Modules 

Sat Sep 28 11:01:36 CDT 2024

## Description

Display all your installed Perl Modules

and

display perldoc for a selected module

## Installation

cpanm Sumu::Perl::Modules

or 

cpanm CEEJAY/Sumu-Perl-Modules-0.1.1.tar.gz

## USAGE

Clone this repo to get started 




### Latest Update/Release Info 

Latest Update/release info (added automatically)


#### 20240928195449CDT

	012\|013
	0.1.2\|0.1.3


#### 20240928195649CDT

	013|014
	0.1.3|0.1.4


#### 20240928195922CDT

	Commit ID: 014|015
	Version ID: 0.1.4|0.1.5


#### 20240928200135CDT

	Commit ID: Old 015 | New 016
	Version ID: Old 0.1.5 | New 0.1.6


#### 2024-09-28 20:05:50 CDT

	Commit ID: Old 016 | New 017
	Version ID: Old 0.1.6 | New 0.1.7


#### 2024-09-28 20:08:31 CDT

	Commit ID: Old 017 | New 018
	Version ID: Old 0.1.7 | New 0.1.8


#### 2024-09-28 20:09:13 CDT

	Commit ID: Old 018 | New 019
	Version ID: Old 0.1.8 | New 0.1.9


#### 2024-09-28 20:11:23 CDT

	Commit ID: Old 019 | New 020
	Version ID: Old 0.1.9 | New 0.2.0


#### 2024-09-28 20:19:35 CDT

	Commit ID: Old 020 | New 021
	Version ID: Old 0.2.0 | New 0.2.1


#### 2024-09-28 20:23:35 CDT

	Commit ID: Old 021 | New 022
	Version ID: Old 0.2.1 | New 0.2.2


#### 2024-09-28 20:27:22 CDT

	Commit ID: Old 022 | New 023
	Version ID: Old 0.2.2 | New 0.2.3


#### 2024-09-28 20:30:08 CDT

	Commit ID: Old 023 | New 024
	Version ID: Old 0.2.3 | New 0.2.4


#### 2024-09-28 20:30:54 CDT

	Commit ID: Old 024 | New 025
	Version ID: Old 0.2.4 | New 0.2.5


#### 2024-09-28 20:44:09 CDT

	Commit ID: Old 025 | New 026
	Version ID: Old 0.2.5 | New 0.2.6


#### 2024-09-28 20:49:41 CDT

	Commit ID: Old 026 | New 027
	Version ID: Old 0.2.6 | New 0.2.7


#### 2024-09-28 20:57:00 CDT

	Commit ID: Old 027 | New 028
	Version ID: Old 0.2.7 | New 0.2.8


#### 2024-09-28 20:59:35 CDT

	Commit ID: Old 028 | New 029
	Version ID: Old 0.2.8 | New 0.2.9


#### 2024-09-28 21:10:49 CDT

	Commit ID: Old 029 | New 030
	Version ID: Old 0.2.9 | New 0.3.0


#### 2024-09-28 21:31:35 CDT

	Commit ID: Old 030 | New 031
	Version ID: Old 0.3.0 | New 0.3.1


#### 2024-09-28 21:34:08 CDT

	Commit ID: Old 031 | New 032
	Version ID: Old 0.3.1 | New 0.3.2


#### 2024-09-28 21:44:41 CDT

	Commit ID: Old 032 | New 033
	Version ID: Old 0.3.2 | New 0.3.3


#### 2024-09-29 08:46:47 CDT

	Commit ID: Old 033 | New 034
	Version ID: Old 0.3.3 | New 0.3.4


#### 2024-09-30 07:33:47 CDT

	Commit ID: Old 034 | New 035
	Version ID: Old 0.3.4 | New 0.3.5


#### 2024-09-30 07:59:07 CDT

	Commit ID: Old 035 | New 036
	Version ID: Old 0.3.5 | New 0.3.6


#### 2024-09-30 08:41:46 CDT

	Commit ID: Old 036 | New 037
	Version ID: Old 0.3.6 | New 0.3.7


#### 2024-10-01 08:46:34 CDT

	Commit ID: Old 037 | New 038
	Version ID: Old 0.3.7 | New 0.3.8


#### 2024-10-01 09:07:07 CDT

	Commit ID: Old 038 | New 039
	Version ID: Old 0.3.8 | New 0.3.9


#### 2024-10-01 09:16:16 CDT

	Commit ID: Old 039 | New 040
	Version ID: Old 0.3.9 | New 0.4.0
